#GBR analysis
#arrange multiple ternary plots nicely
#panels for raw data, perturbing vectors, fitted models, risk, stationary distributions

rm(list=ls())

library(boot)
library(car)
library(compositions)
library(expm)
library(mvtnorm)
library(RColorBrewer)
library(Cairo)
library(maps)
library(mapdata)
library(ncf)
library(sp)
library(mvoutlier)

source("modelfitting3.R")
fgbr <- "gbrnoise.txt" #NOTE THE REEF COMPOSITION DATA HAVE ADDED NOISE, BECAUSE WE DO NOT HAVE PERMISSION TO DISTRIBUTE THEM IN ORIGINAL FORM. CAN BE USED TO DEMONSTRATE THE CODE, BUT NOT FOR ANALYSIS
bootgbr <- "gbrcurrentboot.RData"
bootplus1gbr <- "gbrplus1boot.RData"
bootplus2gbr <- "gbrplus2boot.RData"
bootgbrmed <- "gbrcurrentmedboot.RData"
bootplus1gbrmed <- "gbrplus1medboot.RData"
bootplus2gbrmed <- "gbrplus2medboot.RData"

plotdatamodel <- TRUE #plot raw data, perturbing vectors, and fitted model?
runbootstrap <- TRUE #produce new bootstrap data?
runbootstrap1 <- FALSE #bootstrap at +1 climatology?
plotbootstrap <- TRUE #plot bootstrap results?
plotbootstrap1 <- FALSE #plot bootstrap results at +1 climatology?
plotbootstrap012 <- FALSE #plot stationary distribution at current, +1 and +2?
plotrisktruncate <- FALSE #plot probability of undesirable compositions, only up to +2 climatology
reportstability <- FALSE #report eigenvalue info?
getSSTequivalent <- TRUE #express low vs medium threat in equivalent degrees warming?
plotSSTdirection <- TRUE #short- and long-term directions of climatology effects
getclimanom <- FALSE #if long-term effect is anomaly instead of climatology, how much is a degree of warming worth relative to climatology model?
coastdistfig <- FALSE #figure showing locations
AICtable <- FALSE #table of AIC for alternative models
spatialresids <- FALSE #spatial autocorrelation of residuals
simulateobserror <- FALSE #effects of simulated observation error
checkresids <- FALSE #diagnostics based on residuals
writemoviedata <- FALSE #export data for animations

if(plotdatamodel){
	par(mfrow=c(3,1),mar=c(0.5,1,0.5,1),oma=c(0,0,0,0),xpd=TRUE)
        darkbgcol <- "black"
	plotraw(fgbr,mono=FALSE,bgcol=darkbgcol)
	text(0,0.8,"A: raw",pos=4)
	ssticks <- plotperturbbySST(fgbr,bgcol=darkbgcol)
	text(0,0.8,"B: perturbing\nvectors",pos=4)

        dfgbr <- builddata(fgbr)
	mgbr <- testmodels(dfgbr)
	plotmodel(mgbr,makelegend=TRUE,plotvariance=TRUE,bgcol=darkbgcol,lx=1,ly=0.75,lwd=1)
	text(0,0.8,"C: model",pos=4)

        colorcode <- colorRamp(rev(brewer.pal(9,"RdBu")))
        cl <- seq(0,1,length.out=100)
        colorlevels <- rgb(colorcode(cl),max=255)
        colorBarpoly(colvals=colorlevels,zlim=c(0,1),parfig=c(0.6,0.9,0.5,0.6),tlabs=ssticks$tlabs,tpos=ssticks$tpos,title=expression(paste("SST anomaly (",degree,"C)")))
}

if(runbootstrap){
	reps <- 10 #SMALL NUMBER USED FOR TEST (1e4 used for manuscript)
	grid <- 2.5 #FOR QUICK TEST (LARGER NUMBERS GIVE PLOTS THAT GO CLOSER TO EDGES OF SIMPLEX, SET TO 4 IN MANUSCRIPT)
	gridstep <- 0.1
	dmes <- "Lebesgue"
	nlevels <- 20
	trunc <- 50
	threatgbr <- "Low"
	threatgbr2 <- "Medium"
	lthresh <- 1
	alphacoral <- 0.1
	alphaalgae <- 0.5
	xpoints <- NULL
	xplabs <- NULL
	
	dfgbr <- builddata(fgbr)
	mgbr <- fitbasemodel(dfgbr)
	sststatsgbr <- getsststats(fgbr)
        sstsetgbr <- seq(from=floor(sststatsgbr$crange[1]),to=sststatsgbr$cmu1+3.5,length.out=100)
        bvecgbr <- dobootstrap(df=dfgbr,reps=reps,s2=sststatsgbr$cmu1,mu2=sststatsgbr$cmu1,sigma2=sststatsgbr$csigma1,gr=grid,grst=gridstep,dmes=dmes,nlevels=nlevels,trunc=trunc,threat=threatgbr,lthresh=lthresh,maxcol=NULL,sstset=sstsetgbr,alphacoral=alphacoral,alphaalgae=alphaalgae,sststats=sststatsgbr,xpoints=xpoints,xplabs=xplabs)
        save(list=c("bvecgbr","reps","grid","gridstep","dmes","nlevels","trunc","threatgbr","lthresh","alphacoral","alphaalgae","dfgbr","mgbr","sststatsgbr","sstsetgbr","xpoints","xplabs"),file=bootgbr)
	rm(bvecgbr)
        
	bvecgbr2 <- dobootstrap(df=dfgbr,reps=reps,s2=sststatsgbr$cmu1+2,mu2=sststatsgbr$cmu1,sigma2=sststatsgbr$csigma1,gr=grid,grst=gridstep,dmes=dmes,nlevels=nlevels,trunc=trunc,threat=threatgbr,lthresh=lthresh,maxcol=NULL,sstset=sstsetgbr,alphacoral=alphacoral,alphaalgae=alphaalgae,sststats=sststatsgbr,xpoints=xpoints,xplabs=xplabs)
        save(list=c("bvecgbr2","reps","grid","gridstep","dmes","nlevels","trunc","threatgbr","threatgbr2","lthresh","alphacoral","alphaalgae","dfgbr","mgbr","sststatsgbr","sstsetgbr","xpoints","xplabs"),file=bootplus2gbr)
	rm(bvecgbr2)

	bvecgbrmed <- dobootstrap(df=dfgbr,reps=reps,s2=sststatsgbr$cmu1,mu2=sststatsgbr$cmu1,sigma2=sststatsgbr$csigma1,gr=grid,grst=gridstep,dmes=dmes,nlevels=nlevels,trunc=trunc,threat=threatgbr2,lthresh=lthresh,maxcol=NULL,sstset=sstsetgbr,alphacoral=alphacoral,alphaalgae=alphaalgae,sststats=sststatsgbr,xpoints=xpoints,xplabs=xplabs)
	save(list=c("bvecgbrmed","reps","grid","gridstep","dmes","nlevels","trunc","threatgbr","threatgbr2","lthresh","alphacoral","alphaalgae","dfgbr","mgbr","sststatsgbr","sstsetgbr","xpoints","xplabs"),file=bootgbrmed)
	rm(bvecgbrmed)

	bvecgbrmed2 <- dobootstrap(df=dfgbr,reps=reps,s2=sststatsgbr$cmu1+2,mu2=sststatsgbr$cmu1,sigma2=sststatsgbr$csigma1,gr=grid,grst=gridstep,dmes=dmes,nlevels=nlevels,trunc=trunc,threat=threatgbr2,lthresh=lthresh,maxcol=NULL,sstset=sstsetgbr,alphacoral=alphacoral,alphaalgae=alphaalgae,sststats=sststatsgbr,xpoints=xpoints,xplabs=xplabs)
	save(list=c("bvecgbrmed2","reps","grid","gridstep","dmes","nlevels","trunc","threatgbr","threatgbr2","lthresh","alphacoral","alphaalgae","dfgbr","mgbr","sststatsgbr","sstsetgbr","xpoints","xplabs"),file=bootplus2gbrmed)
	rm(bvecgbrmed2)
        
    }

if(runbootstrap1){

	reps <- 1e4
	grid <- 4
	gridstep <- 0.1
	dmes <- "Lebesgue"
	nlevels <- 20
	trunc <- 50
	threatgbr <- "Low"
	threatgbr2 <- "Medium"
	lthresh <- 1
	alphacoral <- 0.1
	alphaalgae <- 0.5
	xpoints <- NULL
	xplabs <- NULL
	
	dfgbr <- builddata(fgbr)
	mgbr <- fitbasemodel(dfgbr)
	sststatsgbr <- getsststats(fgbr)
        sstsetgbr <- seq(from=floor(sststatsgbr$crange[1]),to=sststatsgbr$cmu1+3.5,length.out=100)

        
	bvecgbr1 <- dobootstrap(df=dfgbr,reps=reps,s2=sststatsgbr$cmu1+1,mu2=sststatsgbr$cmu1,sigma2=sststatsgbr$csigma1,gr=grid,grst=gridstep,dmes=dmes,nlevels=nlevels,trunc=trunc,threat=threatgbr,lthresh=lthresh,maxcol=NULL,sstset=sstsetgbr,alphacoral=alphacoral,alphaalgae=alphaalgae,sststats=sststatsgbr,xpoints=xpoints,xplabs=xplabs)
        save(list=c("bvecgbr1","reps","grid","gridstep","dmes","nlevels","trunc","threatgbr","threatgbr2","lthresh","alphacoral","alphaalgae","dfgbr","mgbr","sststatsgbr","sstsetgbr","xpoints","xplabs"),file=bootplus1gbr)
	rm(bvecgbr1)

	bvecgbrmed1 <- dobootstrap(df=dfgbr,reps=reps,s2=sststatsgbr$cmu1+1,mu2=sststatsgbr$cmu1,sigma2=sststatsgbr$csigma1,gr=grid,grst=gridstep,dmes=dmes,nlevels=nlevels,trunc=trunc,threat=threatgbr2,lthresh=lthresh,maxcol=NULL,sstset=sstsetgbr,alphacoral=alphacoral,alphaalgae=alphaalgae,sststats=sststatsgbr,xpoints=xpoints,xplabs=xplabs)
	save(list=c("bvecgbrmed1","reps","grid","gridstep","dmes","nlevels","trunc","threatgbr","threatgbr2","lthresh","alphacoral","alphaalgae","dfgbr","mgbr","sststatsgbr","sstsetgbr","xpoints","xplabs"),file=bootplus1gbrmed)
	rm(bvecgbrmed1)
    }


if(plotbootstrap){
	load(bootgbr)
	load(bootplus2gbr)
	load(bootgbrmed)
	load(bootplus2gbrmed)

        bresgbr <- extractboot(bvec=bvecgbr,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
        bresgbr2 <- extractboot(bvec=bvecgbr2,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
        bresgbrmed <- extractboot(bvec=bvecgbrmed,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
        bresgbrmed2 <- extractboot(bvec=bvecgbrmed2,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)

	X11()
	plot2marginalSSTboots(bres=bresgbr,bres2=bresgbrmed,sstset=sstsetgbr,alphacoral=alphacoral,alphaalgae=alphaalgae,mu2=sststatsgbr$cmu1,sststats=sststatsgbr,xpoints=xpoints,xplabs=xplabs,labs=c("low threat","medium\nthreat","low threat","medium\nthreat")) #plot bootstrapped marginal risk for GBR

        #plot bootstrap mean sensitivity
        X11()
        par(mfrow=c(2,1),mar=c(0.5,1,0.5,1),oma=c(0,0,0,0),xpd=TRUE)        
        senstrunc <- 20
        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootsenspoly(bres=bresgbr,grid=grid,gridstep=gridstep,truncv=senstrunc,sfunc="mean") 
        text(0,0.8,"A: low threat",adj=c(0,NA))
        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootsenspoly(bres=bresgbrmed,grid=grid,gridstep=gridstep,truncv=senstrunc,sfunc="mean") 
        text(0,0.8,"B: medium\nthreat",adj=c(0,NA))
        colorBarfor2poly(zlim=c(-senstrunc,senstrunc),pos=-1)

        X11() #bootstrap sd sensitivity
        par(mfrow=c(2,1),mar=c(0.5,1,0.5,1),oma=c(0,0,0,0),xpd=TRUE)        
        senstrunc <- 20
        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootsenspoly(bres=bresgbr,grid=grid,gridstep=gridstep,truncv=senstrunc,sfunc="sd") 
        text(0,0.8,"A: low threat",adj=c(0,NA))
        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootsenspoly(bres=bresgbrmed,grid=grid,gridstep=gridstep,truncv=senstrunc,sfunc="sd") 
        text(0,0.8,"B: medium\nthreat",adj=c(0,NA))
        colorBarfor2poly(zlim=c(0,senstrunc),pos=-1,colorcode=colorRamp(brewer.pal(9,"Greys")))

        X11() #plot bootstrap mean stationary distributions at low and medium threat, current and +2 climatology
        denstrunc <- 20
        sf <- "mean" #change to "sd" to get standard deviation
        par(mfcol=c(2,2),mar=c(4,1,0.5,1),oma=c(0,0,0,0))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbr,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"A: current\nclimatology,\nlow threat",adj=c(0,NA))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbr2,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"C: +2 climatology,\nlow threat",adj=c(0,NA))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbrmed,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"B: current\nclimatology,\nmedium threat",adj=c(0,NA))
        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbrmed2,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
text(0,0.8,"D: +2 climatology,\nmedium threat",adj=c(0,NA))
        colorBarfor4poly(zlim=c(0,denstrunc),pos=1)

        X11() #plot bootstrap sd stationary distributions at low and medium threat, current and +2 climatology
        denstrunc <- 20
        sf <- "sd"
        par(mfcol=c(2,2),mar=c(4,1,0.5,1),oma=c(0,0,0,0))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbr,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"A: current\nclimatology,\nlow threat",adj=c(0,NA))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbr2,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"C: +2 climatology,\nlow threat",adj=c(0,NA))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbrmed,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"B: current\nclimatology,\nmedium threat",adj=c(0,NA))
        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbrmed2,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
text(0,0.8,"D: +2 climatology,\nmedium threat",adj=c(0,NA))
        colorBarfor4poly(zlim=c(0,denstrunc),pos=1)
        
        
    }

if(plotbootstrap1){
	load(bootgbr)
	load(bootplus1gbr)
	load(bootgbrmed)
	load(bootplus1gbrmed)

        bresgbr <- extractboot(bvec=bvecgbr,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
        bresgbr1 <- extractboot(bvec=bvecgbr1,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
        bresgbrmed <- extractboot(bvec=bvecgbrmed,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
        bresgbrmed1 <- extractboot(bvec=bvecgbrmed1,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)

        X11() #plot bootstrap mean stationary distributions at low and medium threat, current and +1 climatology
        denstrunc <- 20
        sf <- "mean" #change to "sd" to get standard deviation
        par(mfcol=c(2,2),mar=c(4,1,0.5,1),oma=c(0,0,0,0))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbr,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"A: current\nclimatology,\nlow threat",adj=c(0,NA))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbr1,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"C: +1 climatology,\nlow threat",adj=c(0,NA))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbrmed,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"B: current\nclimatology,\nmedium threat",adj=c(0,NA))
        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbrmed1,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
text(0,0.8,"D: +1 climatology,\nmedium threat",adj=c(0,NA))
        colorBarfor4poly(zlim=c(0,denstrunc),pos=1)

        X11() #plot bootstrap sd stationary distributions at low and medium threat, current and +1 climatology
        denstrunc <- 20
        sf <- "sd"
        par(mfcol=c(2,2),mar=c(4,1,0.5,1),oma=c(0,0,0,0))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbr,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"A: current\nclimatology,\nlow threat",adj=c(0,NA))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbr1,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"C: +1 climatology,\nlow threat",adj=c(0,NA))

        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbrmed,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
        text(0,0.8,"B: current\nclimatology,\nmedium threat",adj=c(0,NA))
        plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
        bootdenspoly(bres=bresgbrmed1,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
text(0,0.8,"D: +1 climatology,\nmedium threat",adj=c(0,NA))
        colorBarfor4poly(zlim=c(0,denstrunc),pos=1)
        
        
    }

if(plotbootstrap012){
    load(bootgbr)
    load(bootplus1gbr)
    load(bootplus2gbr)
    load(bootgbrmed)
    load(bootplus1gbrmed)
    load(bootplus2gbrmed)

    bresgbr <- extractboot(bvec=bvecgbr,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
    bresgbr1 <- extractboot(bvec=bvecgbr1,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
    bresgbr2 <- extractboot(bvec=bvecgbr2,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
    bresgbrmed <- extractboot(bvec=bvecgbrmed,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
    bresgbrmed1 <- extractboot(bvec=bvecgbrmed1,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
    bresgbrmed2 <- extractboot(bvec=bvecgbrmed2,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
    denstrunc <- 20
    
    sf <- "mean" #change to "sd" to get standard deviation

    par(mfcol=c(3,2),mar=c(0.75,0,0,0),oma=c(0,0,0,0))
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"A: current\nclimatology,\nlow threat",adj=c(0,NA))
    bootdenspoly(bres=bresgbr,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"C: +1\nclimatology,\nlow threat",adj=c(0,NA))
    bootdenspoly(bres=bresgbr1,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"E: +2\nclimatology,\nlow threat",adj=c(0,NA))
    bootdenspoly(bres=bresgbr2,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 


    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"B: current\nclimatology,\nmedium\nthreat",adj=c(0,NA))
    bootdenspoly(bres=bresgbrmed,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"D: +1\nclimatology,\nmedium\nthreat",adj=c(0,NA))
    bootdenspoly(bres=bresgbrmed1,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"F: +2\nclimatology,\nmedium\nthreat",adj=c(0,NA))
    bootdenspoly(bres=bresgbrmed2,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    colorBarfor6poly(zlim=c(0,denstrunc))


    sf <- "sd"

    par(mfcol=c(3,2),mar=c(0.75,0,0,0),oma=c(0,0,0,0))
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"A: current\nclimatology,\nlow threat",adj=c(0,NA))
    bootdenspoly(bres=bresgbr,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"C: +1\nclimatology,\nlow threat",adj=c(0,NA))
    bootdenspoly(bres=bresgbr1,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"E: +2\nclimatology,\nlow threat",adj=c(0,NA))
    bootdenspoly(bres=bresgbr2,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 


    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"B: current\nclimatology,\nmedium\nthreat",adj=c(0,NA))
    bootdenspoly(bres=bresgbrmed,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"D: +1\nclimatology,\nmedium\nthreat",adj=c(0,NA))
    bootdenspoly(bres=bresgbrmed1,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    plot(acomp(c(1,1,1)),type="n",labels=c("coral","algae","other")) 
    text(0,0.8,"F: +2\nclimatology,\nmedium\nthreat",adj=c(0,NA))
    bootdenspoly(bres=bresgbrmed2,grid=grid,gridstep=gridstep,measure="Lebesgue",truncv=denstrunc,sfunc=sf) 
    colorBarfor6poly(zlim=c(0,denstrunc))

}

if(plotrisktruncate){
    load(bootgbr)
    load(bootgbrmed)
    bresgbr <- extractboot(bvec=bvecgbr,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
    bresgbrmed <- extractboot(bvec=bvecgbrmed,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)
    plot2marginalSSTboots(bres=bresgbr,bres2=bresgbrmed,sstset=sstsetgbr,alphacoral=alphacoral,alphaalgae=alphaalgae,mu2=sststatsgbr$cmu1,sststats=sststatsgbr,xpoints=xpoints,xplabs=xplabs,labs=c("low threat","medium threat","low threat","medium threat"),truncatesst=2) #plot bootstrapped marginal risk for GBR, only up to +2 above current mean climatology

}


if(reportstability){
	load(bootgbr)
	bresgbr <- extractboot(bvec=bvecgbr,grid=grid,gridstep=gridstep,lthresh=lthresh,sstset=sstsetgbr)

	#do we have any complex eigenvalues?
	X11()
	ploteigen(bresgbr)

	print("GBR:")
	print("bootstrap proportion stable")
	print(getproportionstable(bres=bresgbr)$pstab)
	print("bootstrap mean of abs(largest eigenvalue)")
	print(getproportionstable(bres=bresgbr)$lmean)
	print("bootstrap st dev of abs(largest eigenvalue)")
	print(getproportionstable(bres=bresgbr)$lsd)
    }


if(getSSTequivalent){#how many degrees warming of climatology is medium vs low threat equivalent to?
  reps <- 1e4
  dfgbr <- builddata(fgbr)
  mgbr <- fitbasemodel(dfgbr)
  sststatsgbr <- getsststats(fgbr)
  SSTeq <- SSTequivalent(model=mgbr,sigma2=sststatsgbr$csigma1)
  print(SSTeq)
  SSTeqboot <- boot(dfgbr,bootSSTeq,R=reps,sigma2=sststatsgbr$csigma1)
  print("bootstrap mean long term climatology equivalent of medium threat")
  print(mean(SSTeqboot$t[,3]))
  print("bootstrap 95% CI")
  print(boot.ci(SSTeqboot,conf=0.95,index=3,type="bca"))
  print("bootstrap mean long term proportion of medium vs low in climatology direction")
  print(mean(SSTeqboot$t[,4]))
  print("bootstrap 95% CI")
  print(boot.ci(SSTeqboot,conf=0.95,index=4,type="bca"))
}

if(getclimanom){#if long-term warming effect is described by anomaly rather than climatology parameter, how much is a degree warming worth relative to climatology model?
  reps <- 1e4
  dfgbr <- builddata(fgbr)
  mgbr <- fitbasemodel(dfgbr)
  sststatsgbr <- getsststats(fgbr)
  clan <- climanom(model=mgbr,sigma1=sststatsgbr$asigma1,sigma2=sststatsgbr$csigma1)
  print(clan)
  clanboot <- boot(dfgbr,bootclimanom,R=reps,sigma1=sststatsgbr$asigma1,sigma2=sststatsgbr$csigma1)
  print("bootstrap mean value of 1 degree warming under anomaly relative to climatology model")
  print(mean(clanboot$t[,1]))
  print("bootstrap 95% CI")
  print(boot.ci(clanboot,conf=0.95,index=1,type="bca"))
  print("bootstrap mean long term proportion of anomaly effect in climatology direction")
  print(mean(clanboot$t[,2]))
  print("bootstrap 95% CI")
  print(boot.ci(clanboot,conf=0.95,index=2,type="bca"))
}


if(plotSSTdirection){
    dfgbr <- builddata(fgbr)
    mgbr <- fitbasemodel(dfgbr)
    sststatsgbr <- getsststats(fgbr)
    X11()
    SSTdirectionplot(model=mgbr,s2=sststatsgbr$cmu1,mu2=sststatsgbr$cmu1,sigma2=sststatsgbr$csigma1)
}

if(coastdistfig){

    dfgbr <- builddata(fgbr)
    mgbr <- fitbasemodel(dfgbr)
    resids <- residuals(mgbr)
    testresids <- aq.plot(resids)
    graphics.off()
    makesitemap(dfgbr,testresids$outlier)
    gbr <- read.table(file=fgbr,header=TRUE,sep="\t")
    boxplot(coastdistkm~factor(threat,levels=c("Low","Medium","High","Very High")),data=gbr,ylab="Distance from coast/km",xlab="Local threat")
}

if(AICtable){
    gbr <- builddata(fgbr)
    msstlag <- lm(cbind(z1,z2) ~ cbind(o1,o2) + sstlag + threat, data=gbr)
    msst <- lm(cbind(z1,z2) ~ cbind(o1,o2) + sst + threat, data=gbr)
    msstalag <- lm(cbind(z1,z2) ~ cbind(o1,o2) + sstalag + threat, data=gbr)
    mssta <- lm(cbind(z1,z2) ~ cbind(o1,o2) + ssta + threat, data=gbr)
    msstaclimlag <- lm(cbind(z1,z2) ~ cbind(o1,o2) + sstalag + climlag + threat, data=gbr)
    msstlagdist <- lm(cbind(z1,z2) ~ cbind(o1,o2) + sstlag + coastdistkm, data=gbr)
    msstdist <- lm(cbind(z1,z2) ~ cbind(o1,o2) + sst + coastdistkm, data=gbr)
    msstalagdist <- lm(cbind(z1,z2) ~ cbind(o1,o2) + sstalag + coastdistkm, data=gbr)
    msstadist <- lm(cbind(z1,z2) ~ cbind(o1,o2) + ssta + coastdistkm, data=gbr)
    msstaclimlagdist <- lm(cbind(z1,z2) ~ cbind(o1,o2) + sstalag + climlag + coastdistkm, data=gbr)
    mclimlag <- lm(cbind(z1,z2) ~ cbind(o1,o2) + climlag + threat, data=gbr)
    mclim <- lm(cbind(z1,z2) ~ cbind(o1,o2) + clim + threat, data=gbr)
    mclimlagdist <- lm(cbind(z1,z2) ~ cbind(o1,o2) + climlag + coastdistkm, data=gbr)
    mclimdist <- lm(cbind(z1,z2) ~ cbind(o1,o2) + clim + coastdistkm, data=gbr)



    AICvals <- data.frame(name=character(14),edf=numeric(14),AIC=numeric(14))

    AICvals[,1] <- c("SST, threat","Lagged SST, threat","SST anomaly, threat","Lagged SST anomaly, threat","Lagged SST anomaly, lagged climatology, threat", "SST, distance","Lagged SST, distance","SST anomaly, distance","Lagged SST anomaly, distance","Lagged SST anomaly, lagged climatology, distance","Lagged climatology, threat","Climatology, threat","Lagged climatology, distance","Climatology, distance")

    AICvals[1,2:3] <- extractAIC(msst)
    AICvals[2,2:3] <- extractAIC(msstlag)
    AICvals[3,2:3] <- extractAIC(mssta)
    AICvals[4,2:3] <- extractAIC(msstalag)
    AICvals[5,2:3] <- extractAIC(msstaclimlag)
    AICvals[6,2:3] <- extractAIC(msstdist)
    AICvals[7,2:3] <- extractAIC(msstlagdist)
    AICvals[8,2:3] <- extractAIC(msstadist)
    AICvals[9,2:3] <- extractAIC(msstalagdist)
    AICvals[10,2:3] <- extractAIC(msstaclimlagdist)
    AICvals[11,2:3] <- extractAIC(mclimlag)
    AICvals[12,2:3] <- extractAIC(mclim)
    AICvals[13,2:3] <- extractAIC(mclimlagdist)
    AICvals[14,2:3] <- extractAIC(mclimdist)
    
    AICvals <- AICvals[order(AICvals$AIC),]
    print(AICvals)
    write.table(AICvals,file="../results/AICtable.txt",row.names=FALSE,quote=FALSE,sep="\t")
}
if(spatialresids){
    gbr <- builddata(fgbr)
    mgbr <- fitbasemodel(gbr)
    p4longlat <- CRS("+proj=longlat +ellps=WGS84 +towgs84=0,0,0 +nodefs")
    coordinates(gbr) <- c("long","lat")
    proj4string(gbr) <- p4longlat
    plotspatialcorr(dff=gbr,model=mgbr,resamp=1000) #multivariate, spline correlograms: Bjornstad and Falck 2001 Env & Ecol Stat 8:53-70
}

if(simulateobserror){
    npoints <- 3000 #number of points observed under multinomial sampling
    reps <- 1e4
    doplot <- "mean"
    dosim <- TRUE #run simulations and save to simnoise.RData? (otherwise load from file simnoise.RData)
    
    dfgbr <- builddata(fgbr)
    mgbr <- fitbasemodel(dfgbr)
    nparms <- dim(coef(mgbr))[1]
    sststatsgbr <- getsststats(fgbr)
   if(!(doplot=="none")){
        darkbgcol <- "black"
        plotmodel(mgbr,makelegend=TRUE,plotvariance=TRUE,bgcol=darkbgcol,lx=0.65,ly=1,lwd=1)
        colors <- c("grey","#56B4E9","#0072B2" , "#009E73", "#CC79A7","#F0E442","#E69F00","#D55E00")
    }
    if(dosim){
    snoise <- simnoise(model=mgbr,df=dfgbr,reps=reps,npoints=npoints,doplot=doplot,s2=sststatsgbr$cmu1,mu2=sststatsgbr$cmu1,sigma2=sststatsgbr$csigma1)
    save(snoise,file="../results/simnoise.RData")
} else{
    load("../results/simnoise.RData")
}
    if(doplot=="mean"){
        for(i in 1:nparms){
            addpointcoord(snoise$simmeans[i,],pch=3,color=colors[i])
        }
        vellipsemean(Sigma=matrix(snoise$simmeans[(nparms+1):(nparms+2),],nrow=2,ncol=2),color=adjustcolor("grey",0.7),lty="dotted",lwd=1)
    }

    X11()
    arrowbias(trumu=snoise$trumu,trumusens=snoise$trumusens,simmumean=snoise$simmumean,simmusensmean=snoise$simmusensmean)
    
}

if(checkresids){
    dfgbr <- builddata(fgbr)
    mgbr <- testmodels(dfgbr)
    resids <- residuals(mgbr)
    fits <- fitted.values(mgbr)
    testresids <- aq.plot(resids)
    trimdata <- dfgbr[testresids$outlier==FALSE,]
    mtrim <- testmodels(trimdata)
    
    residvexplan(resids=resids,fits=fits,df=dfgbr)

    residvyear(resids=resids,df=dfgbr)

    predvobs(model=mgbr,df=dfgbr)
    
    plotresidscatter(resids,testresids$outlier)

    darkbgcol <- "black"
    plotmodel(mtrim,makelegend=TRUE,plotvariance=TRUE,bgcol=darkbgcol,lx=0.65,ly=1,lwd=1)
}

if(writemoviedata){
    dfgbr <- builddata(fgbr)
    mgbr <- fitbasemodel(dfgbr)
    B <- getB(model=mgbr)
    Sigmastar <- getSigmastar(model=mgbr)
    sststatsgbr <- getsststats(fgbr)

#the things we need to write out to Matlab
    outdata <- rbind(B,Sigmastar,coef(mgbr),c(sststatsgbr$cmu1,sststatsgbr$csigma1))
    rownames(outdata)[1] <- "b1"
    rownames(outdata)[2] <- "b2"
    rownames(outdata)[3] <- "Sigmastar1"
    rownames(outdata)[4] <- "Sigmastar2"
    rownames(outdata)[6] <- "a1"
    rownames(outdata)[7] <- "a2"
    rownames(outdata)[13] <- "climmusd"
    write.table(outdata,file="../interactive/gbrmodel2.txt",sep="\t",quote=FALSE,col.names=FALSE)

}
